system_base_pkgs:
  pkg.installed:
    - pkgs:
      - linux-lts
      - linux-firmware-none
      - openjdk17-jre-headless
      - jq
      - vim
      - git

system_base_bin_dir:
  file.directory:
    - name: /usr/local/noveria/bin
    - makedirs: true
    - user: root
    - group: root
    - dir_mode: '0755'
    - file_mode: '0644'

system_base_apps_dir:
  file.directory:
    - name: /usr/local/noveria/apps
    - makedirs: true
    - user: root
    - group: root
    - dir_mode: '0755'
    - file_mode: '0644'

{% set OS_VERSION = salt['cmd.shell']('date "+%Y%m"') %}

system_base_os-release:
  file.managed:
    - name: /etc/os-release
    - source: salt://{{ tpldir }}/files/base_os-release.jinja
    - template: jinja
    - context:
        OS_VERSION: {{ OS_VERSION }}}
    - user: root
    - group: root
    - mode: '0644'

{% set NAME = salt['cmd.shell']('grep -E ^NAME /etc/os-release | cut -d= -f2 | sed \'s|"||g\'') %}
{% set VERSION_ID = salt['cmd.shell']('grep -E ^VERSION_ID /etc/os-release | cut -d= -f2 | sed \'s|"||g\'') %}

system_base_motd:
  file.managed:
    - name: /etc/motd
    - source: salt://{{ tpldir }}/files/base_motd.jinja
    - template: jinja
    - context:
        OS: {{ NAME }}
        OS_VERSION: {{ VERSION_ID }}
    - user: root
    - group: root
    - mode: '0644'
    - require:
      - system_base_os-release